# Pyscicat
Pyscicat is a python client library for interacting with the [SciCat backend](https://scicatproject.github.io/). It sends messages to the SciCat backend over HTTP. It currently does not contain any command line interface.

Documentation for Pyscicat can be found is [available here](https://scicatproject.github.io/pyscicat/)
